@@ -18,7 +18,6 @@ class QSnapdClient;
 class SnapResource : public AbstractResource
 {
     Q_OBJECT
-    Q_PROPERTY(QStringList topObjects MEMBER m_topObjects CONSTANT)
     Q_PROPERTY(QString channel READ channel WRITE setChannel NOTIFY channelChanged)
 public:
     explicit SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::State state, SnapBackend *parent);
@@ -64,9 +63,15 @@ public:
     Q_SCRIPTABLE QObject *channels(QObject *parent);
     QString appstreamId() const override;
 
+    QStringList topObjects() const override;
+
     QString channel() const;
     void setChannel(const QString &channel);
 
+    quint64 installedSize() const;
+    quint64 downloadSize() const;
+    void updateSizes();
+
     QSharedPointer<QSnapdSnap> snap() const
     {
         return m_snap;
@@ -81,8 +86,10 @@ public:
     void refreshSnap();
     void gotIcon();
     AbstractResource::State m_state;
+    quint64 m_installedSize;
+    quint64 m_downloadSize;
 
     QSharedPointer<QSnapdSnap> m_snap;
     mutable QVariant m_icon;
-    static const QStringList m_topObjects;
+    static const QStringList s_topObjects;
 };
